.. _all-salt.modules:

======================================
Full list of builtin execution modules
======================================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.pkg

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aliases
    alternatives
    apache
    aptpkg
    archive
    at
    augeas_cfg
    aws_sqs
    blockdev
    bluez
    boto_asg
    boto_cloudwatch
    boto_elasticache
    boto_elb
    boto_iam
    boto_route53
    boto_secgroup
    boto_sqs
    brew
    bridge
    bsd_shadow
    cassandra
    chef
    chocolatey
    cloud
    cmdmod
    composer
    config
    cp
    cron
    daemontools
    darwin_sysctl
    data
    ddns
    deb_apache
    debconfmod
    debian_ip
    debian_service
    defaults
    dig
    disk
    djangomod
    dnsmasq
    dnsutil
    dockerio
    dpkg
    ebuild
    eix
    environ
    eselect
    etcd_mod
    event
    extfs
    file
    freebsd_sysctl
    freebsdjail
    freebsdkmod
    freebsdpkg
    freebsdports
    freebsdservice
    gem
    genesis
    gentoo_service
    gentoolkitmod
    git
    glance
    glusterfs
    gnomedesktop
    grains
    groupadd
    grub_legacy
    guestfs
    hadoop
    haproxyconn
    hashutil
    hg
    hosts
    htpasswd
    img
    incron
    influx
    ini_manage
    introspect
    ipset
    iptables
    junos
    key
    keyboard
    keystone
    kmod
    launchctl
    layman
    ldapmod
    linux_acl
    linux_lvm
    linux_sysctl
    localemod
    locate
    logadm
    logrotate
    lvs
    lxc
    mac_group
    mac_user
    macports
    makeconf
    match
    mdadm
    memcached
    mine
    mod_random
    modjk
    mongodb
    monit
    moosefs
    mount
    munin
    mysql
    nagios
    netbsd_sysctl
    netbsdservice
    network
    nfs3
    nftables
    nginx
    nova
    npm
    omapi
    openbsdpkg
    openbsdservice
    openstack_config
    oracle
    osxdesktop
    pacman
    pagerduty
    pam
    parted
    pecl
    pillar
    pip
    pkg_resource
    pkgin
    pkgng
    pkgutil
    portage_config
    postfix
    postgres
    poudriere
    powerpath
    ps
    publish
    puppet
    pw_group
    pw_user
    pyenv
    qemu_img
    qemu_nbd
    quota
    rabbitmq
    raet_publish
    rbenv
    rdp
    redismod
    reg
    rest_package
    rest_sample
    rest_service
    ret
    rh_ip
    rh_service
    riak
    rpm
    rsync
    rvm
    s3
    saltcloudmod
    saltutil
    schedule
    seed
    selinux
    sensors
    serverdensity_device
    service
    shadow
    smartos_imgadm
    smartos_vmadm
    smf
    smtp
    softwareupdate
    solaris_group
    solaris_shadow
    solaris_user
    solarispkg
    solr
    sqlite3
    ssh
    state
    status
    supervisord
    svn
    swift
    sysbench
    sysmod
    system
    systemd
    test
    timezone
    tls
    tomcat
    twilio_notify
    upstart
    useradd
    uwsgi
    varnish
    virt
    virtualenv_mod
    win_autoruns
    win_disk
    win_dns_client
    win_file
    win_firewall
    win_groupadd
    win_ip
    win_network
    win_ntp
    win_path
    win_pkg
    win_repo
    win_servermanager
    win_service
    win_shadow
    win_status
    win_system
    win_timezone
    win_update
    win_useradd
    xapi
    xmpp
    yumpkg
    zcbuildout
    zfs
    znc
    zpool
    zypper
